@@ -1,26 +1,11 @@
-/* ****************************************************************************
+/*
   This file is part of Lokalize
 
-  Copyright (C) 2008-2014 by Nick Shaforostoff <shafff@ukr.net>
-                2018-2019 by Simon Depiets <sdepiets@gmail.com>
+  SPDX-FileCopyrightText: 2008-2014 Nick Shaforostoff <shafff@ukr.net>
+  SPDX-FileCopyrightText: 2018-2019 Simon Depiets <sdepiets@gmail.com>
 
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License as
-  published by the Free Software Foundation; either version 2 of
-  the License or (at your option) version 3 or any later version
-  accepted by the membership of KDE e.V. (or its successor approved
-  by the membership of KDE e.V.), which shall act as a proxy
-  defined in Section 14 of version 3 of the license.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
-**************************************************************************** */
+  SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 
 #ifndef LOKALIZEMAINWINDOW_H
 #define LOKALIZEMAINWINDOW_H
@@ -44,7 +29,6 @@ class LokalizeMdiArea;
 class KRecentFilesAction;
 class EditorTab;
 class MultiEditorAdaptor;
-class ProjectScriptingPlugin;
 class FileSearchTab;
 namespace TM
 {
@@ -86,7 +70,6 @@ private Q_SLOTS:
     void applyToBeActiveSubWindow();
     void projectLoaded();
     void projectSettingsChanged();
-    void loadProjectScripts();
 
     void editorClosed(QObject* obj);
     void resetMultiEditorAdaptor();
@@ -176,7 +159,6 @@ private:
     //used for kross API
     EditorTab* m_spareEditor;
     MultiEditorAdaptor* m_multiEditorAdaptor;
-    ProjectScriptingPlugin* m_projectScriptingPlugin;
 
     //using QPointer switches it.value() to 0 before we get to destroyed() handler
     //typedef QMap<QUrl, QPointer<QMdiSubWindow> > FileToEditor;
@@ -192,21 +174,6 @@ public Q_SLOTS:
     void activatePreviousSubWindow();
 };
 
-#include <kross/ui/plugin.h>
-
-class ProjectScriptingPlugin: public Kross::ScriptingPlugin
-{
-    Q_OBJECT
-public:
-    ProjectScriptingPlugin(QObject* lokalize, QObject* editor);
-    ~ProjectScriptingPlugin();
-    void setDOMDocument(const QDomDocument &document, bool merge = false) override;
-
-private Q_SLOTS:
-    void doAutoruns();
-};
-
-
 class DelayedFileOpener: public QObject
 {
     Q_OBJECT
