@@ -1,26 +1,12 @@
-/* ****************************************************************************
+/*
   This file is part of Lokalize
 
-  Copyright (C) 2007-2014 by Nick Shaforostoff <shafff@ukr.net>
-                2018-2019 by Simon Depiets <sdepiets@gmail.com>
+  SPDX-FileCopyrightText: 2007-2014 Nick Shaforostoff <shafff@ukr.net>
+  SPDX-FileCopyrightText: 2018-2019 Simon Depiets <sdepiets@gmail.com>
+  SPDX-FileCopyrightText: 2023 Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
 
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License as
-  published by the Free Software Foundation; either version 2 of
-  the License or (at your option) version 3 or any later version
-  accepted by the membership of KDE e.V. (or its successor approved
-  by the membership of KDE e.V.), which shall act as a proxy
-  defined in Section 14 of version 3 of the license.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
-**************************************************************************** */
+  SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 
 #include "projecttab.h"
 #include "project.h"
@@ -198,7 +184,7 @@ ProjectTab::ProjectTab(QWidget *parent)
 
     //    ADD_ACTION_SHORTCUT_ICON("edit_find",i18nc("@action:inmenu","Find in files"),Qt::ALT+Qt::Key_Down,"nextpo")
     //connect(action, &QAction::triggered, this, &ProjectTab::gotoNextTransOnly);
-    action = nav->addAction(KStandardAction::Find, this, SLOT(searchInFiles()));
+    action = nav->addAction(KStandardAction::Find, this, SLOT(findTriggered()));
 
     KActionCategory* proj = new KActionCategory(i18nc("@title actions category", "Project"), ac);
 
@@ -327,6 +313,12 @@ void ProjectTab::addComment()
     Project::instance()->save();
 }
 
+void ProjectTab::findTriggered()
+{
+  // Allows the Edit->Find menu to hide itself before it gets deleted afterwards.
+  QMetaObject::invokeMethod(this, [this](){searchInFiles(false);}, Qt::QueuedConnection);
+}
+
 void ProjectTab::searchInFiles(bool templ)
 {
     QStringList files = m_browser->selectedItems();
